
:autogenerated:

krotov.parallelization module
=============================

.. currentmodule:: krotov.parallelization

.. automodule:: krotov.parallelization
    :members: Consumer, FwPropStepTask, USE_LOKY, USE_THREADPOOL_LIMITS, parallel_map, parallel_map_fw_prop_step, set_parallelization
    :undoc-members:
    :show-inheritance:
    :member-order: bysource

    Summary
    -------

    Classes:

    .. autosummary::
        :nosignatures:

        Consumer
        FwPropStepTask

    Functions:

    .. autosummary::
        :nosignatures:

        parallel_map
        parallel_map_fw_prop_step
        set_parallelization





    ``__all__``: :class:`Consumer <krotov.parallelization.Consumer>`, :class:`FwPropStepTask <krotov.parallelization.FwPropStepTask>`, :func:`parallel_map <krotov.parallelization.parallel_map>`, :func:`parallel_map_fw_prop_step <krotov.parallelization.parallel_map_fw_prop_step>`, :func:`serial_map <qutip.parallel.serial_map>`, :func:`set_parallelization <krotov.parallelization.set_parallelization>`



    Reference
    ---------